@@ -4,3 +4,5 @@ pub mod three_point_circle;
 pub mod center_and_radius_circle;
 pub mod free_hand_line;
 pub mod foci_and_point_ellipse;
+pub mod grid;
+pub mod free_grid;
